==> zio-aws-firehose_2.13-7.28.26.1-sources.jar: zio/aws/firehose/model/HiveJsonSerDe.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.NonEmptyString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class HiveJsonSerDe(
    timestampFormats: Optional[Iterable[NonEmptyString]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.HiveJsonSerDe = {
    import HiveJsonSerDe.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
      .builder()
      .optionallyWith(
        timestampFormats.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.timestampFormats)
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.HiveJsonSerDe.ReadOnly =
    zio.aws.firehose.model.HiveJsonSerDe.wrap(buildAwsValue())
}
object HiveJsonSerDe {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.HiveJsonSerDe =
      zio.aws.firehose.model.HiveJsonSerDe(timestampFormats.map(value => value))
    def timestampFormats: Optional[List[NonEmptyString]]
    def getTimestampFormats: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("timestampFormats", timestampFormats)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ) extends zio.aws.firehose.model.HiveJsonSerDe.ReadOnly {
    override val timestampFormats: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.timestampFormats())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.firehose.model.primitives.NonEmptyString(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ): zio.aws.firehose.model.HiveJsonSerDe.ReadOnly = new Wrapper(impl)
}

==> zio-aws-firehose_3-5.17.104.5-sources.jar: zio/aws/firehose/model/HiveJsonSerDe.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.NonEmptyString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class HiveJsonSerDe(
    timestampFormats: Option[Iterable[NonEmptyString]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.HiveJsonSerDe = {
    import HiveJsonSerDe.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
      .builder()
      .optionallyWith(
        timestampFormats.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.timestampFormats)
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.HiveJsonSerDe.ReadOnly =
    zio.aws.firehose.model.HiveJsonSerDe.wrap(buildAwsValue())
}
object HiveJsonSerDe {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.HiveJsonSerDe =
      zio.aws.firehose.model.HiveJsonSerDe(timestampFormats.map(value => value))
    def timestampFormats: Option[List[NonEmptyString]]
    def getTimestampFormats: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("timestampFormats", timestampFormats)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ) extends zio.aws.firehose.model.HiveJsonSerDe.ReadOnly {
    override val timestampFormats: Option[List[NonEmptyString]] = scala
      .Option(impl.timestampFormats())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.firehose.model.primitives.NonEmptyString(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.HiveJsonSerDe
  ): zio.aws.firehose.model.HiveJsonSerDe.ReadOnly = new Wrapper(impl)
}
